Examples
========
Frontdoor-Backdoor Example
--------------------------
.. automodapi:: eliater.frontdoor_backdoor
    :no-heading:
    :include-all-objects:

Frontdoor-Backdoor Discrete Example
-----------------------------------
.. automodapi:: eliater.examples.frontdoor_backdoor_discrete
    :no-heading:
    :include-all-objects:

Escherichia coli K-12 Example
-----------------------------
.. automodapi:: eliater.examples.ecoli
    :no-heading:
    :include-all-objects:

SARS-CoV-2 Example
------------------
.. automodapi:: eliater.examples.sars
    :no-heading:
    :include-all-objects:

T cell signaling pathway Example
--------------------------------
.. automodapi:: eliater.examples.t_cell_signaling_pathway
    :no-heading:
    :include-all-objects:
